@@ -137,7 +137,7 @@ sub get_start_line_chunk {
 
 sub is_secure {
   my $url = shift->url;
-  return ($url->scheme || $url->base->scheme) ~~ 'https';
+  return ($url->scheme || $url->base->scheme // '') eq 'https';
 }
 
 sub is_xhr {
@@ -159,7 +159,8 @@ sub parse {
 
   # CGI like environment
   $self->env($env)->_parse_env($env) if $env;
-  $self->content($self->content->parse_body(@args)) if $self->{state} ~~ 'cgi';
+  $self->content($self->content->parse_body(@args))
+    if ($self->{state} // '') eq 'cgi';
 
   # Pass through
   $self->SUPER::parse(@args);
@@ -188,8 +189,6 @@ sub parse {
   return $self;
 }
 
-# "Bart, with $10,000, we'd be millionaires!
-#  We could buy all kinds of useful things like...love!"
 sub proxy {
   my $self = shift;
   return $self->{proxy} unless @_;
@@ -220,7 +219,7 @@ sub _parse_env {
     # Host/Port
     if ($name eq 'HOST') {
       my ($host, $port) = ($value, undef);
-      ($host, $port) = ($1, $2) if $host =~ /^([^\:]*)\:?(.*)$/;
+      ($host, $port) = ($1, $2) if $host =~ /^([^:]*):?(.*)$/;
       $base->host($host)->port($port);
     }
   }
