@@ -52,7 +52,8 @@ sub app {
 
   # Default to singleton application
   return $self->{app} || $singleton unless $app;
-  return $self->tap(sub { $_->{app} = $app });
+  $self->{app} = $app;
+  return $self;
 }
 
 sub app_url {
@@ -501,8 +502,7 @@ sub _write {
   warn "-- Client >>> Server (@{[$tx->req->url->to_abs]})\n$chunk\n" if DEBUG;
 
   # Write chunk
-  my $stream = $self->_loop->stream($id);
-  $stream->write($chunk);
+  my $stream = $self->_loop->stream($id)->write($chunk);
   $self->_handle($id) if $tx->is_finished;
 
   # Continue writing
