@@ -38,7 +38,7 @@ has static   => sub { Mojolicious::Static->new };
 has types    => sub { Mojolicious::Types->new };
 
 our $CODENAME = 'Rainbow';
-our $VERSION  = '3.36';
+our $VERSION  = '3.37';
 
 sub AUTOLOAD {
   my $self = shift;
@@ -571,7 +571,8 @@ Mount whole L<Mojolicious> applications.
 
 =item L<Mojolicious::Plugin::PODRenderer>
 
-Renderer for POD files and documentation browser.
+Renderer for turning POD into HTML and documentation browser for
+L<Mojolicious::Guides>.
 
 =item L<Mojolicious::Plugin::PoweredBy>
 
